MemorySigner

Struct MemorySigner 

pub struct MemorySigner { /* private fields */ }
A Solana-based signer that uses an in-memory keypair

Implementations

Source

impl MemorySigner

pub fn new(keypair: Keypair) -> Self

Creates a new signer from a Solana keypair

pub fn from_bytes(private_key: &[u8]) -> Result<Self, SignerError>

Creates a new signer from a private key byte array

pub fn from_private_key_string(private_key: &str) -> Result<Self, SignerError>

Creates a new signer from a private key string that can be in multiple formats:

  • Base58 encoded string
  • U8Array format: “[0, 1, 2, …]”
  • File path to a JSON keypair file