pub struct MemorySigner { /* private fields */ }Expand description
A Solana-based signer that uses an in-memory keypair
Implementations
Sourceimpl MemorySigner
impl MemorySigner
Sourcepub fn from_bytes(private_key: &[u8]) -> Result<Self, SignerError>
pub fn from_bytes(private_key: &[u8]) -> Result<Self, SignerError>
Creates a new signer from a private key byte array
Sourcepub fn from_private_key_string(private_key: &str) -> Result<Self, SignerError>
pub fn from_private_key_string(private_key: &str) -> Result<Self, SignerError>
Creates a new signer from a private key string that can be in multiple formats:
- Base58 encoded string
- U8Array format: “[0, 1, 2, …]”
- File path to a JSON keypair file